@@ -654,26 +654,7 @@ void basic_server<selector_type>::reopen_impl(unsigned int port, bool ipv6)
 	selector_type& selector = basic_object<selector_type>::get_selector();
 
 	// Open IPv4 socket on local port
-	if(!ipv6)
-	{
-		ipv4_address bind_addr(port);
-		serv_sock.reset(new tcp_server_socket(bind_addr) );
-
-		selector.set(*serv_sock,
-			selector.get(*serv_sock) | IO_INCOMING
-		);
-
-		serv_sock->io_event().connect(
-			sigc::bind<0>(
-				sigc::mem_fun(
-					*this,
-					&basic_server::on_accept_event
-				),
-				sigc::ref(*serv_sock)
-			)
-		);
-	}
-	else
+	if(ipv6)
 	{
 		ipv6_address bind_addr(port);
 		serv6_sock.reset(new tcp_server_socket(bind_addr) );
@@ -692,6 +673,32 @@ void basic_server<selector_type>::reopen_impl(unsigned int port, bool ipv6)
 			)
 		);
 	}
+
+	// This might fail if bindv6only
+	// (/proc/sys/net/ipv6/bindv6only) is 0
+	try
+	{
+		ipv4_address bind_addr(port);
+		serv_sock.reset(new tcp_server_socket(bind_addr) );
+
+		selector.set(*serv_sock,
+			selector.get(*serv_sock) | IO_INCOMING
+		);
+
+		serv_sock->io_event().connect(
+			sigc::bind<0>(
+				sigc::mem_fun(
+					*this,
+					&basic_server::on_accept_event
+				),
+				sigc::ref(*serv_sock)
+			)
+		);
+	}
+	catch(const net6::error& ex)
+	{
+		if(!ipv6) throw ex;
+	}
 }
 
 } // namespace net6
